Django Development Server Integration — Transmogrify 1.0.1b1 documentation

Transmogrify 1.0.1b1 documentation

# Django Development Server Integration

- Table of Contents
- index
  next
  previous

# Django Development Server Integration

`transmogrify.views.transmogrify_serve`

    from django.conf import settings

    if settings.DEBUG:
        urlpatterns += patterns('',
            (r'^static/(?P<path>.*)$', 'transmogrify.views.transmogrify_serve',
                {'document_root': settings.MEDIA_ROOT}),
        )